@@ -20,9 +20,18 @@ def get_repo(path, search_parent_directories=True):
 
 
 def get_file_blob(repo, filename):
+    from git.index.typ import BlobFilter
+
     idx = repo.index
-    rel_filepath = os.path.relpath(filename, repo.working_dir)
-    blob = next(idx.iter_blobs(lambda _: _[1].path == rel_filepath))[1]
+
+    repo_dir = os.path.abspath(repo.working_dir)
+
+    filename = os.path.abspath(filename)
+    filename = os.path.relpath(filename, repo_dir)
+    filename = os.path.normpath(filename)
+
+    blob = next(idx.iter_blobs(BlobFilter(filename)))[1]
+
     return blob
 
 
@@ -49,6 +58,10 @@ def set_mode_file(filename, mode):
 
 @contextmanager
 def write_file(filename):
+    dirname = os.path.dirname(filename)
+    if dirname and not os.path.exists(dirname):
+        os.makedirs(dirname)
+
     with open(filename, "w") as fh:
         yield fh
 
@@ -71,6 +84,10 @@ def remove_file(filename):
 
     os.remove(filename)
 
+    dirname = os.path.dirname(filename)
+    if dirname and not os.listdir(dirname):
+        os.removedirs(dirname)
+
 
 def copy_file(src, dst):
     shutil.copy2(src, dst)
